X
@@ -362,7 +701,23 @@
+
+
diff --git a/src/components/TestPlatform/Plan/PlanExecute.vue b/src/components/TestPlatform/Plan/PlanExecute.vue
index 07f4420..1fee5b3 100644
--- a/src/components/TestPlatform/Plan/PlanExecute.vue
+++ b/src/components/TestPlatform/Plan/PlanExecute.vue
@@ -27,13 +27,13 @@
style="margin-top: 12px;">
-
-
-
- 打开
- -
-
+
+ {{ scope.row.modulePath || '—' }}
+
+ {{ scope.row.moduleName || '—' }}
+
+
@@ -162,9 +162,10 @@ export default {
statusLabel: this.formatExecuteStatus(item.status),
actualResult: item.actual_result || item.actualResult || '',
caseKey: item.case_key || item.caseKey || '',
+ modulePath: item.module_path || item.modulePath || '',
+ moduleName: item.module_name || item.moduleName || '',
caseTitle: item.case_title || item.caseTitle || item.title || '',
- title: item.title || item.case_title || item.caseTitle || '',
- jenkinsUrl: item.jenkins_url || item.jenkinsUrl || ''
+ title: item.title || item.case_title || item.caseTitle || ''
}))
})
.catch(() => {
diff --git a/src/components/TestPlatform/SkillRule/BusinessSkillRuleConfig.vue b/src/components/TestPlatform/SkillRule/BusinessSkillRuleConfig.vue
new file mode 100644
index 0000000..21bc4a7
--- /dev/null
+++ b/src/components/TestPlatform/SkillRule/BusinessSkillRuleConfig.vue
@@ -0,0 +1,820 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 查询
+
+
+ 重置
+
+
+ 新建 Skill
+
+
+
+
+
+
+
+ {{ formatSkillType(scope.row.skill_type) }}
+
+
+ {{ formatRiskLevel(scope.row.risk_level) }}
+
+
+ {{ formatConfigStatus(scope.row.status) }}
+
+
+ {{ formatTagsCol(scope.row.tags) }}
+
+
+
+
+ 编辑
+ 删除
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 查询
+
+
+ 重置
+
+
+ 新建规则
+
+
+
+
+
+
+
+ {{ formatPriority(scope.row.priority) }}
+
+
+ {{ formatConfigStatus(scope.row.status) }}
+
+
+ {{ formatTagsCol(scope.row.tags) }}
+
+
+
+
+ 编辑
+ 删除
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 取消
+ 保存
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 取消
+ 保存
+
+
+
+
+
+
+
+
diff --git a/src/router/index.js b/src/router/index.js
index 16a7734..7872a5f 100644
--- a/src/router/index.js
+++ b/src/router/index.js
@@ -96,6 +96,13 @@ export default new Router({
Manage: (resolve) => require(['@/components/TestPlatform/Project/ProjectSettings'], resolve)
}
},
+ {
+ path: '/test-platform/skill-rules',
+ name: 'BusinessSkillRuleConfig',
+ components: {
+ Manage: (resolve) => require(['@/components/TestPlatform/SkillRule/BusinessSkillRuleConfig'], resolve)
+ }
+ },
{
path: '/test-platform/case',
name: 'CaseList',
diff --git a/src/utils/bugStepsFormat.js b/src/utils/bugStepsFormat.js
index 8f1d808..76dff6a 100644
--- a/src/utils/bugStepsFormat.js
+++ b/src/utils/bugStepsFormat.js
@@ -41,7 +41,7 @@ export function normalizeUploadPathSlashes(url) {
/**
* 静态资源(Bug 上传图)访问根,不含末尾 /
- * - 开发环境默认 http://localhost:5010(与后端文件服务常见端口一致)
+ * - 开发环境默认 http://localhost:8881(与后端文件服务常见端口一致)
* - 可在 index.html 里设置 window.__BUG_UPLOAD_ORIGIN__ 覆盖
* - 打包时可配置 VUE_APP_BUG_UPLOAD_ORIGIN(需在 webpack DefinePlugin 中注入)
*/
@@ -56,14 +56,14 @@ export function getBugUploadStaticOrigin() {
} catch (e) { /* ignore */ }
try {
if (typeof process !== 'undefined' && process.env && process.env.NODE_ENV === 'development') {
- return 'http://localhost:5010'
+ return 'http://localhost:8881'
}
} catch (e2) { /* ignore */ }
return ''
}
/**
- * 浏览器实际加载图片用的地址:/uploads/... 在开发环境走 5010 端口
+ * 浏览器实际加载图片用的地址:/uploads/... 在开发环境走 8881 端口
* 存库仍可为接口返回的完整 URL,仅展示/预览时改写
*/
export function rewriteBugImageUrlForAccess(url) {
@@ -155,7 +155,7 @@ export function isStepsLikelyHtml(s) {
return /<\s*(p|div|br|img|span|ul|ol|li|h[1-6]|table|strong|em)\b/i.test(String(s || '').trim())
}
/** 将 HTML 中 img 的 src 改写为可访问地址(开发环境 /uploads → 5010) */
export function rewriteImgSrcsInHtml(html) {
return String(html || '').replace(/(
]*\bsrc\s*=\s*)(["'])([^"']*)\2/gi, function (_m, pre, q, src) {
@@ -155,7 +155,7 @@ export function isStepsLikelyHtml(s) {
return /<\s*(p|div|br|img|span|ul|ol|li|h[1-6]|table|strong|em)\b/i.test(String(s || '').trim())
}
-/** 将 HTML 中 img 的 src 改写为可访问地址(开发环境 /uploads → 5010) */
+/** 将 HTML 中 img 的 src 改写为可访问地址(开发环境 /uploads → 8881) */
export function rewriteImgSrcsInHtml(html) {
return String(html || '').replace(/(
const fixed = rewriteBugImageUrlForAccess(normalizeUploadPathSlashes(src))